---
name: "\U0001F6A8 Submit a Bug Report"
about: Use this template if you came across a bug or unexpected behaviour differing from the docs.
labels: bug
---

## How to reproduce the behaviour
<!-- Include a code example or the steps that led to the problem. Please try to be as specific as possible. -->

## Your Environment
<!-- Include details of your environment. If you're using spaCy 1.7+, you can also type `python -m spacy info --markdown` and copy-paste the result here along with the DaCy version which you can get using `python -c "import dacy; print(dacy.__version__)"`.-->
* DaCy Version Used:
* Operating System:
* Python Version Used:
* spaCy Version Used:
* Environment Information: